( cd usr/lib ; rm -rf libORBit-2.so.0 )
( cd usr/lib ; ln -sf libORBit-2.so.0.0.0 libORBit-2.so.0 )
( cd usr/lib ; rm -rf libORBit-2.so )
( cd usr/lib ; ln -sf libORBit-2.so.0.0.0 libORBit-2.so )
( cd usr/lib ; rm -rf libORBitCosNaming-2.so.0 )
( cd usr/lib ; ln -sf libORBitCosNaming-2.so.0.0.0 libORBitCosNaming-2.so.0 )
( cd usr/lib ; rm -rf libORBitCosNaming-2.so )
( cd usr/lib ; ln -sf libORBitCosNaming-2.so.0.0.0 libORBitCosNaming-2.so )
( cd usr/lib ; rm -rf libORBit-imodule-2.so.0 )
( cd usr/lib ; ln -sf libORBit-imodule-2.so.0.0.0 libORBit-imodule-2.so.0 )
( cd usr/lib ; rm -rf libORBit-imodule-2.so )
( cd usr/lib ; ln -sf libORBit-imodule-2.so.0.0.0 libORBit-imodule-2.so )
