#ifndef ORB_CORE_H
#define ORB_CORE_H 1

#include <orbit/util/orbit-util.h>

#include <orbit/orb-core/corba-defs.h>
#include <orbit/orb-core/iop-defs.h>

#include <orbit/orb-core/corba-orb.h>
#include <orbit/orb-core/corba-string.h>

#include <orbit/orb-core/corba-environment.h>
#include <orbit/orb-core/corba-any.h>
#include <orbit/orb-core/corba-object-type.h>
#include <orbit/orb-core/corba-object.h>
#include <orbit/orb-core/corba-policy-type.h>
#include <orbit/orb-core/corba-context.h>

#include <orbit/orb-core/orbit-small.h>

#endif
